@@ -61,7 +61,7 @@ class ComposeFamily:
     """
 
     def __init__(self, services, family_name):
-        self._services = services
+        self._compose_services = services
         self.ordered_services = services
         self.managed_sidecars = []
         self.name = family_name
@@ -77,6 +77,8 @@ class ComposeFamily:
         self.umbrella_log_group = None
         self.firelens_service = None
         self.firelens_config_service = None
+        self.cwagent_service = None
+        self.xray_service = None
         self.task_definition = None
         self.service_definition = None
         self.service_tags = None
@@ -223,6 +225,38 @@ class ComposeFamily:
         """
         set_xray(self)
         set_prometheus(self)
+        self.set_services_family_links()
+
+    def set_services_family_links(self):
+        for service in self.ordered_services:
+            if service.links:
+                for link in service.links:
+                    for _svc in self.ordered_services:
+                        if _svc == service:
+                            continue
+                        if _svc.name in link:
+                            service.family_links.append(link)
+            if self.xray_service and self.xray_service.name not in service.family_links:
+                service.family_links.append(self.xray_service.name)
+            if (
+                self.cwagent_service
+                and self.cwagent_service.name not in service.family_links
+            ):
+                service.family_links.append(f"{self.cwagent_service.name}:cwagent")
+            if service.family_links:
+                setattr(
+                    service.container_definition,
+                    "Links",
+                    If(
+                        ecs_conditions.USE_WINDOWS_OS_T,
+                        NoValue,
+                        If(
+                            ecs_conditions.USE_BRIDGE_NETWORKING_MODE_CON_T,
+                            service.family_links,
+                            NoValue,
+                        ),
+                    ),
+                )
 
     def generate_outputs(self):
         """
@@ -268,7 +302,7 @@ class ComposeFamily:
         LOG.info(f"{self.name} - LaunchType set to {self.service_compute.launch_type}")
         LOG.info(
             f"{self.name} - TaskDefinition containers: "
-            f"{[svc.name for svc in chain(self.ordered_services, self.managed_sidecars)]}"
+            f"{[svc.name for svc in self.services]}"
         )
 
     def add_service(self, service: ComposeService):
@@ -280,7 +314,7 @@ class ComposeFamily:
 
         from .task_execute_command import set_enable_execute_command
 
-        self._services.append(service)
+        self._compose_services.append(service)
 
         self.set_update_containers_priority()
         self.iam_manager.init_update_policies()
@@ -503,7 +537,10 @@ class ComposeFamily:
         """
         Method to sort out the containers dependencies and create the containers definitions based on the configs.
         """
-        service_configs = [[0, service] for service in self.services]
+        service_configs = [
+            [0, service]
+            for service in list(chain(self._compose_services, self.managed_sidecars))
+        ]
         handle_same_task_services_dependencies(service_configs)
         ordered_containers_config = sorted(service_configs, key=lambda i: i[0])
         self.ordered_services = [s[1] for s in ordered_containers_config]
